@@ -223,6 +223,10 @@ fn generate_bitfields(w: &mut dyn Write, env: &Env, items: &[&Bitfield]) -> Resu
                 .find_map(|m| m.version)
                 .or(member.version);
 
+            if member_config.iter().any(|m| m.status.ignored()) {
+                continue;
+            }
+
             let val: i64 = member.value.parse().unwrap();
 
             version_condition(w, env, None, version, false, 0)?;
@@ -323,13 +327,12 @@ fn generate_enums(w: &mut dyn Write, env: &Env, items: &[&Enumeration]) -> Resul
             let member_config = config
                 .as_ref()
                 .map_or_else(Vec::new, |c| c.members.matched(&member.name));
-            let is_alias = member_config.iter().any(|m| m.alias);
             let version = member_config
                 .iter()
                 .find_map(|m| m.version)
                 .or(member.version);
 
-            if is_alias {
+            if member_config.iter().any(|m| m.status.ignored()) {
                 continue;
             }
 
@@ -403,6 +406,7 @@ fn generate_opaque_type(w: &mut dyn Write, name: &str) -> Result<()> {
     writeln!(
         w,
         r#"#[repr(C)]
+#[allow(dead_code)]
 pub struct {name} {{
     _data: [u8; 0],
     _marker: core::marker::PhantomData<(*mut u8, core::marker::PhantomPinned)>,
@@ -543,6 +547,11 @@ fn generate_from_fields(
         generate_opaque_type(w, &fields.name)?;
     } else {
         writeln!(w, "#[repr(C)]")?;
+
+        if fields.truncated.is_some() {
+            writeln!(w, "#[allow(dead_code)]")?;
+        }
+
         writeln!(
             w,
             "pub {kind} {name} {{",
